@@ -4,7 +4,7 @@ use 5.022001;
 use strict;
 use warnings;
 
-our $VERSION = "1.0";
+our $VERSION = "1.0.1";
 
 # for reading in configs
 use File::Slurp;
@@ -238,6 +238,9 @@ sub do_the_installation {
 		$self->create_config_files($config_file);
 	}
 
+	# symlink over code map
+	symlink $self->{options}{othome}.'/distribution/configs/ot6_modules.yml', $self->{options}{othome}.'/configs/ot6_modules.yml';
+
 	# if the user who will run OT6 is not the same username running this script, run a chown
 	if ($ENV{USER} ne $self->{options}{'omnitool-username'}) {
 		system('chown -R '.$self->{options}{'omnitool-username'}.' '.$self->{options}{othome});
@@ -353,6 +356,11 @@ sub create_config_files {
 	# save the new file under OTHOME/configs
 	write_file($destination_file, $output);
 
+	# if it's start_omnitool.bash.tt, make it executable
+	if ($config_filename eq 'start_omnitool.bash.tt') {
+		chmod 0744, $destination_file;
+	}
+
 	# symlink over code map
 	symlink $self->{options}{othome}.'/distribution/configs/ot6_modules.yml', $self->{options}{othome}.'/configs/ot6_modules.yml';
 
